==> haskell-xdg-basedir-0.2.2-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-basedir.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xdg-basedir
version:              0.2.2
visibility:           public
id:                   xdg-basedir-0.2.2-DeGg1ryr7ndmwRYCQYweT
key:                  xdg-basedir-0.2.2-DeGg1ryr7ndmwRYCQYweT
license:              BSD-3-Clause
copyright:            (c) 2011 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            alpha
homepage:             http://github.com/willdonnelly/xdg-basedir
synopsis:
    A basic implementation of the XDG Base Directory specification.

description:
    On Unix platforms, this should be a very straightforward
    implementation of the XDG Base Directory spec. On Windows,
    it will attempt to do the right thing with regards to
    choosing appropriate directories.

category:             System
abi:                  56666dc6e90875288024254e01fdc616
exposed:              True
exposed-modules:      System.Environment.XDG.BaseDir
import-dirs:          /usr/lib/ghc-9.0.2/site-local/xdg-basedir-0.2.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/xdg-basedir-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/xdg-basedir-0.2.2
hs-libraries:         HSxdg-basedir-0.2.2-DeGg1ryr7ndmwRYCQYweT
depends:              base-4.15.1.0 directory-1.3.6.2 filepath-1.4.2.1
haddock-interfaces:   /usr/share/doc/haskell-xdg-basedir/html/xdg-basedir.haddock
haddock-html:         /usr/share/doc/haskell-xdg-basedir/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xdg-basedir-0.2.2-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-basedir.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xdg-basedir
version:              0.2.2
visibility:           public
id:                   xdg-basedir-0.2.2-BAENMrhgj9o4xkjbLJyx83
key:                  xdg-basedir-0.2.2-BAENMrhgj9o4xkjbLJyx83
license:              BSD-3-Clause
copyright:            (c) 2011 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            alpha
homepage:             http://github.com/willdonnelly/xdg-basedir
synopsis:
    A basic implementation of the XDG Base Directory specification.

description:
    On Unix platforms, this should be a very straightforward
    implementation of the XDG Base Directory spec. On Windows,
    it will attempt to do the right thing with regards to
    choosing appropriate directories.

category:             System
abi:                  8f115719d198e8614c3de3e58a9b57a5
exposed:              True
exposed-modules:      System.Environment.XDG.BaseDir
import-dirs:          /usr/lib/ghc-9.2.8/site-local/xdg-basedir-0.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/xdg-basedir-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-basedir
hs-libraries:         HSxdg-basedir-0.2.2-BAENMrhgj9o4xkjbLJyx83
depends:              base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2
haddock-interfaces:   /usr/share/doc/haskell-xdg-basedir/html/xdg-basedir.haddock
haddock-html:         /usr/share/doc/haskell-xdg-basedir/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
